@@ -1,10 +1,8 @@
-use serde_derive::Deserialize;
-
 use std::process::Command;
 use std::time::{SystemTime, UNIX_EPOCH};
 
-use docopt::Docopt;
 use notify_rust::Notification;
+use structopt::StructOpt;
 
 struct PackageInfo {
     version: String,
@@ -98,32 +96,16 @@ fn parse_xdpyinfo_output(xdpyinfo_output: &str) -> Option<&str> {
     None
 }
 
-const USAGE: &str = "
-Check the currently installed kernel against the currently running one.
-
-Usage:
-  reboot-arch-btw
-  reboot-arch-btw (-h | --help)
-  reboot-arch-btw --version
-
-Options:
-  -h --help     Show this screen.
-  --version     Show version.
-";
-
-#[derive(Debug, Deserialize)]
+#[derive(Debug, StructOpt)]
+#[structopt(about = "Check the currently installed kernel against the currently running one.")]
 struct Args {
-    flag_version: bool,
+    /// Disable desktop notification
+    #[structopt(long)]
+    disable_notification: bool,
 }
 
 fn main() {
-    let args: Args = Docopt::new(USAGE)
-        .and_then(|d| d.deserialize())
-        .unwrap_or_else(|e| e.exit());
-    if args.flag_version {
-        println!("reboot-arch-btw: {}", env!("CARGO_PKG_VERSION"));
-        return;
-    }
+    let args = Args::from_args();
 
     // Initialize Pacman database
     let alpm = alpm::Alpm::new("/", "/var/lib/pacman/")
@@ -160,13 +142,15 @@ fn main() {
     let should_reboot = !installed_kernel.version_matches(&running_kernel_version);
     if should_reboot {
         println!("You should reboot arch btw!");
-        Notification::new()
-            .summary("Reboot arch btw")
-            .body("Kernel got updated. You should reboot your system!")
-            .timeout(6000) //milliseconds
-            .show()
-            .map_err(|e| println!("Couldn't send notification: {}", e))
-            .ok();
+        if !args.disable_notification {
+            Notification::new()
+                .summary("Reboot arch btw")
+                .body("Kernel got updated. You should reboot your system!")
+                .timeout(6000) //milliseconds
+                .show()
+                .map_err(|e| println!("Couldn't send notification: {}", e))
+                .ok();
+        }
     }
 
     let output_xdpyinfo = Command::new("xdpyinfo")
